# Aerocae robotics controller

Python networking interface for aerocae robotics.

## Install & Upgrade

```
pip install --upgrade aerocae-robotics-controller
```

## Use

```
from arcpy import arcpy

controller = arcpy.Controller('localhost')
...
```